pub struct AuthzServiceClient<T> { /* private fields */ }Expand description
Realm-scoped Zanzibar authorization. Schemas are immutable tenant-owned values; bindings and tuple sets are the mutable authorization state.
Implementations
Sourceimpl<T> AuthzServiceClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> AuthzServiceClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> AuthzServiceClient<InterceptedService<T, F>>where
F: Interceptor,
T::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
pub async fn put_schema( &mut self, request: impl IntoRequest<PutSchemaRequest>, ) -> Result<Response<PutSchemaResponse>, Status>
pub async fn bind_schema( &mut self, request: impl IntoRequest<BindSchemaRequest>, ) -> Result<Response<BindSchemaResponse>, Status>
pub async fn get_binding( &mut self, request: impl IntoRequest<GetBindingRequest>, ) -> Result<Response<GetBindingResponse>, Status>
pub async fn get_schema( &mut self, request: impl IntoRequest<GetSchemaRequest>, ) -> Result<Response<GetSchemaResponse>, Status>
pub async fn mutate_tuples( &mut self, request: impl IntoRequest<MutateTuplesRequest>, ) -> Result<Response<MutateTuplesResponse>, Status>
pub async fn read_tuples( &mut self, request: impl IntoRequest<ReadTuplesRequest>, ) -> Result<Response<ReadTuplesResponse>, Status>
pub async fn check_permission( &mut self, request: impl IntoRequest<CheckPermissionRequest>, ) -> Result<Response<CheckPermissionResponse>, Status>
pub async fn check_permissions( &mut self, request: impl IntoRequest<CheckPermissionsRequest>, ) -> Result<Response<CheckPermissionsResponse>, Status>