#[repr(i32)]pub enum IndexPredicateOperator {
Unspecified = 0,
Equal = 1,
In = 2,
Prefix = 3,
LessThan = 4,
LessThanOrEqual = 5,
GreaterThan = 6,
GreaterThanOrEqual = 7,
Exists = 8,
}Variants
Unspecified = 0
Equal = 1
In = 2
Prefix = 3
LessThan = 4
LessThanOrEqual = 5
GreaterThan = 6
GreaterThanOrEqual = 7
Exists = 8
Implementations
Sourceimpl IndexPredicateOperator
impl IndexPredicateOperator
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of IndexPredicateOperator.
Sourcepub fn from_i32(value: i32) -> Option<IndexPredicateOperator>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<IndexPredicateOperator>
Use the TryFrom<i32> implementation instead
Converts an i32 to a IndexPredicateOperator, or None if value is not a valid variant.
Sourceimpl IndexPredicateOperator
impl IndexPredicateOperator
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.