#[repr(i32)]pub enum ObjectVersioning {
Unversioned = 0,
Enabled = 1,
}Expand description
UNVERSIONED is the meaningful zero/default: replacing or deleting a head does not retain the predecessor for later reads. ENABLED retains versions and is a one-way bucket capability.
Variants
Implementations
Sourceimpl ObjectVersioning
impl ObjectVersioning
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ObjectVersioning.
Sourcepub fn from_i32(value: i32) -> Option<ObjectVersioning>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ObjectVersioning>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ObjectVersioning, or None if value is not a valid variant.
Sourceimpl ObjectVersioning
impl ObjectVersioning
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.