#[repr(i32)]pub enum TenantApplicationRole {
Unspecified = 0,
Owner = 1,
Admin = 2,
Reader = 3,
ManageTenant = 4,
ReadTenant = 5,
ManageBuckets = 6,
ManageAuthz = 7,
}Variants
Unspecified = 0
Owner = 1
Admin = 2
Reader = 3
ManageTenant = 4
ReadTenant = 5
ManageBuckets = 6
ManageAuthz = 7
Implementations
Sourceimpl TenantApplicationRole
impl TenantApplicationRole
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of TenantApplicationRole.
Sourcepub fn from_i32(value: i32) -> Option<TenantApplicationRole>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<TenantApplicationRole>
Use the TryFrom<i32> implementation instead
Converts an i32 to a TenantApplicationRole, or None if value is not a valid variant.
Sourceimpl TenantApplicationRole
impl TenantApplicationRole
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.