pub enum Specification {
Path(PathIndexSpec),
MetadataFilter(MetadataFilterIndexSpec),
TypedJson(TypedJsonIndexSpec),
FullText(FullTextIndexSpec),
Vector(VectorIndexSpec),
Hybrid(HybridIndexSpec),
GitSource(GitSourceIndexSpec),
Tensor(TensorIndexSpec),
}Variants
Path(PathIndexSpec)
MetadataFilter(MetadataFilterIndexSpec)
TypedJson(TypedJsonIndexSpec)
FullText(FullTextIndexSpec)
Vector(VectorIndexSpec)
Hybrid(HybridIndexSpec)
GitSource(GitSourceIndexSpec)
Tensor(TensorIndexSpec)
Implementations
Sourceimpl Specification
impl Specification
Sourcepub fn merge(
field: &mut Option<Specification>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Specification>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.