pub struct AccountingFreshness {
pub refreshed_at: Option<Timestamp>,
pub sources: Vec<AccountingSourceCheckpoint>,
pub complete: bool,
}Fields
refreshed_at: Option<Timestamp>sources: Vec<AccountingSourceCheckpoint>complete: boolFalse only when retained source history was unavailable and the worker had to establish a new current-state baseline.