pub struct AppendPersonalDbEntryRequest {Show 15 fields
pub bucket: String,
pub database_id: String,
pub group_id: String,
pub expected_log_index: u64,
pub expected_log_hash_sha256: Vec<u8>,
pub changeset: Vec<u8>,
pub client_proposal_hash_sha256: Vec<u8>,
pub database_state_root_sha256: Vec<u8>,
pub schema_hash_sha256: Vec<u8>,
pub membership_revision: u64,
pub client_log_epoch: u64,
pub signed_client_proposal: Vec<u8>,
pub signed_voter_acknowledgements: Vec<Vec<u8>>,
pub signed_proposal_admission: Vec<u8>,
pub command_id: String,
}Fields
bucket: Stringdatabase_id: Stringgroup_id: Stringexpected_log_index: u64expected_log_hash_sha256: Vec<u8>changeset: Vec<u8>client_proposal_hash_sha256: Vec<u8>database_state_root_sha256: Vec<u8>schema_hash_sha256: Vec<u8>membership_revision: u64client_log_epoch: u64signed_client_proposal: Vec<u8>signed_voter_acknowledgements: Vec<Vec<u8>>signed_proposal_admission: Vec<u8>command_id: StringTrait Implementations
Sourceimpl Clone for AppendPersonalDbEntryRequest
impl Clone for AppendPersonalDbEntryRequest
Sourcefn clone(&self) -> AppendPersonalDbEntryRequest
fn clone(&self) -> AppendPersonalDbEntryRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AppendPersonalDbEntryRequest
impl Debug for AppendPersonalDbEntryRequest
impl Eq for AppendPersonalDbEntryRequest
Sourceimpl Hash for AppendPersonalDbEntryRequest
impl Hash for AppendPersonalDbEntryRequest
Sourceimpl Message for AppendPersonalDbEntryRequest
impl Message for AppendPersonalDbEntryRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for AppendPersonalDbEntryRequest