pub struct BucketApplicationRoleTarget {
pub bucket: String,
pub role: i32,
}Fields
bucket: Stringrole: i32Implementations
Sourceimpl BucketApplicationRoleTarget
impl BucketApplicationRoleTarget
Sourcepub fn role(&self) -> BucketApplicationRole
pub fn role(&self) -> BucketApplicationRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: BucketApplicationRole)
pub fn set_role(&mut self, value: BucketApplicationRole)
Sets role to the provided enum value.