pub struct BulkPutIfVersionRequest {
pub address: Option<ObjectAddress>,
pub bytes: Vec<u8>,
pub content_type: String,
pub command_id: String,
pub durability: i32,
pub expected_version: u64,
}Fields
address: Option<ObjectAddress>bytes: Vec<u8>content_type: StringEmpty means unspecified; otherwise at most 512 UTF-8 bytes.
command_id: Stringdurability: i32expected_version: u64Implementations
Sourceimpl BulkPutIfVersionRequest
impl BulkPutIfVersionRequest
Sourcepub fn durability(&self) -> Durability
pub fn durability(&self) -> Durability
Returns the enum value of durability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_durability(&mut self, value: Durability)
pub fn set_durability(&mut self, value: Durability)
Sets durability to the provided enum value.