pub struct ChangePersonalDbGroupRoleRequest {
pub bucket: String,
pub database_id: String,
pub group_id: String,
pub app_id: String,
pub role: i32,
pub command_id: String,
}Fields
bucket: Stringdatabase_id: Stringgroup_id: Stringapp_id: Stringrole: i32command_id: StringImplementations
Sourceimpl ChangePersonalDbGroupRoleRequest
impl ChangePersonalDbGroupRoleRequest
Sourcepub fn role(&self) -> PersonalDbGroupRole
pub fn role(&self) -> PersonalDbGroupRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: PersonalDbGroupRole)
pub fn set_role(&mut self, value: PersonalDbGroupRole)
Sets role to the provided enum value.