pub struct CreateBucketRequest {
pub bucket: String,
pub versioning: i32,
}Expand description
A bucket’s durable existence marker and first system-realm owner tuple are written in one metadata batch. The caller becomes that owner.
Fields
bucket: Stringversioning: i32Implementations
Sourceimpl CreateBucketRequest
impl CreateBucketRequest
Sourcepub fn versioning(&self) -> ObjectVersioning
pub fn versioning(&self) -> ObjectVersioning
Returns the enum value of versioning, or the default if the field is set to an invalid enum value.
Sourcepub fn set_versioning(&mut self, value: ObjectVersioning)
pub fn set_versioning(&mut self, value: ObjectVersioning)
Sets versioning to the provided enum value.