pub struct CreateBucketResponse {
pub storage_tenant: String,
pub bucket: String,
pub authorization_revision: u64,
pub replayed: bool,
pub versioning: i32,
}Fields
storage_tenant: Stringbucket: Stringreplayed: boolversioning: i32Implementations
Sourceimpl CreateBucketResponse
impl CreateBucketResponse
Sourcepub fn versioning(&self) -> ObjectVersioning
pub fn versioning(&self) -> ObjectVersioning
Returns the enum value of versioning, or the default if the field is set to an invalid enum value.
Sourcepub fn set_versioning(&mut self, value: ObjectVersioning)
pub fn set_versioning(&mut self, value: ObjectVersioning)
Sets versioning to the provided enum value.