pub struct DeleteIfVersionRequest {
pub address: Option<ObjectAddress>,
pub command_id: String,
pub durability: i32,
pub expected_version: u64,
}Fields
address: Option<ObjectAddress>command_id: Stringdurability: i32expected_version: u64Implementations
Sourceimpl DeleteIfVersionRequest
impl DeleteIfVersionRequest
Sourcepub fn durability(&self) -> Durability
pub fn durability(&self) -> Durability
Returns the enum value of durability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_durability(&mut self, value: Durability)
pub fn set_durability(&mut self, value: Durability)
Sets durability to the provided enum value.