pub struct DeleteVersionRequest {
pub address: Option<ObjectAddress>,
pub version: u64,
pub durability: i32,
}Fields
address: Option<ObjectAddress>version: u64durability: i32Implementations
Sourceimpl DeleteVersionRequest
impl DeleteVersionRequest
Sourcepub fn durability(&self) -> Durability
pub fn durability(&self) -> Durability
Returns the enum value of durability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_durability(&mut self, value: Durability)
pub fn set_durability(&mut self, value: Durability)
Sets durability to the provided enum value.