pub struct IndexOrder {
pub field: String,
pub direction: i32,
}Fields
field: Stringdirection: i32Implementations
Sourceimpl IndexOrder
impl IndexOrder
Sourcepub fn direction(&self) -> IndexOrderDirection
pub fn direction(&self) -> IndexOrderDirection
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: IndexOrderDirection)
pub fn set_direction(&mut self, value: IndexOrderDirection)
Sets direction to the provided enum value.