pub struct IndexPredicate {
pub field: String,
pub operator: i32,
pub values_json: Vec<Vec<u8>>,
}Fields
field: Stringoperator: i32values_json: Vec<Vec<u8>>Each value is one canonical JSON scalar. IN accepts multiple values; EXISTS accepts none; every other operator accepts exactly one.
Implementations
Sourceimpl IndexPredicate
impl IndexPredicate
Sourcepub fn operator(&self) -> IndexPredicateOperator
pub fn operator(&self) -> IndexPredicateOperator
Returns the enum value of operator, or the default if the field is set to an invalid enum value.
Sourcepub fn set_operator(&mut self, value: IndexPredicateOperator)
pub fn set_operator(&mut self, value: IndexPredicateOperator)
Sets operator to the provided enum value.