pub struct InvokeProgramResponse {
pub invocation_id: String,
pub program: Option<ObjectAddress>,
pub program_hash: Vec<u8>,
pub executor_nomination_log_index: u64,
pub commit_log_index: u64,
pub path_receipts: Vec<ProgramPathReceipt>,
pub output_json: Vec<u8>,
pub replayed: bool,
pub replay_guarantee_expires_at: Option<Timestamp>,
}Fields
invocation_id: Stringprogram: Option<ObjectAddress>program_hash: Vec<u8>executor_nomination_log_index: u64commit_log_index: u64path_receipts: Vec<ProgramPathReceipt>output_json: Vec<u8>Canonical JSON object containing the pinned program’s named outputs.
replayed: boolreplay_guarantee_expires_at: Option<Timestamp>Trait Implementations
Sourceimpl Clone for InvokeProgramResponse
impl Clone for InvokeProgramResponse
Sourcefn clone(&self) -> InvokeProgramResponse
fn clone(&self) -> InvokeProgramResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvokeProgramResponse
impl Debug for InvokeProgramResponse
Sourceimpl Default for InvokeProgramResponse
impl Default for InvokeProgramResponse
Sourceimpl Message for InvokeProgramResponse
impl Message for InvokeProgramResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for InvokeProgramResponse
impl PartialEq for InvokeProgramResponse
impl StructuralPartialEq for InvokeProgramResponse