pub struct MutationFailure {
pub code: i32,
pub message: String,
pub current_version: Option<u64>,
}Fields
code: i32message: Stringcurrent_version: Option<u64>Implementations
Sourceimpl MutationFailure
impl MutationFailure
Sourcepub fn code(&self) -> MutationFailureCode
pub fn code(&self) -> MutationFailureCode
Returns the enum value of code, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code(&mut self, value: MutationFailureCode)
pub fn set_code(&mut self, value: MutationFailureCode)
Sets code to the provided enum value.
Sourcepub fn current_version(&self) -> u64
pub fn current_version(&self) -> u64
Returns the value of current_version, or the default value if current_version is unset.