pub struct PersonalDbGroup {
pub descriptor: Vec<u8>,
pub trust_records_json: Vec<Vec<u8>>,
pub replayed: bool,
}Fields
descriptor: Vec<u8>Canonical personaldb-protocol GroupDescriptor bytes.
trust_records_json: Vec<Vec<u8>>Canonical JSON PublicKeyTrustRecord values required to verify descriptors, commit evidence, projection derivations and snapshots returned by Anvil.
replayed: boolTrait Implementations
Sourceimpl Clone for PersonalDbGroup
impl Clone for PersonalDbGroup
Sourcefn clone(&self) -> PersonalDbGroup
fn clone(&self) -> PersonalDbGroup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PersonalDbGroup
impl Debug for PersonalDbGroup
Sourceimpl Default for PersonalDbGroup
impl Default for PersonalDbGroup
impl Eq for PersonalDbGroup
Sourceimpl Hash for PersonalDbGroup
impl Hash for PersonalDbGroup
Sourceimpl Message for PersonalDbGroup
impl Message for PersonalDbGroup
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PersonalDbGroup
impl PartialEq for PersonalDbGroup
impl StructuralPartialEq for PersonalDbGroup