pub struct PrepareNodeResponse {
pub join_bundle_path: String,
pub cluster_id: Vec<u8>,
pub node_id: u64,
pub peer_spki_sha256: Vec<u8>,
}Fields
join_bundle_path: StringServer-local mode-0600 file to copy to the configured joining node and delete after the copy. Private key or capability bytes are never returned in this protobuf response.
cluster_id: Vec<u8>node_id: u64peer_spki_sha256: Vec<u8>Trait Implementations
Sourceimpl Clone for PrepareNodeResponse
impl Clone for PrepareNodeResponse
Sourcefn clone(&self) -> PrepareNodeResponse
fn clone(&self) -> PrepareNodeResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrepareNodeResponse
impl Debug for PrepareNodeResponse
Sourceimpl Default for PrepareNodeResponse
impl Default for PrepareNodeResponse
impl Eq for PrepareNodeResponse
Sourceimpl Hash for PrepareNodeResponse
impl Hash for PrepareNodeResponse
Sourceimpl Message for PrepareNodeResponse
impl Message for PrepareNodeResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PrepareNodeResponse
impl PartialEq for PrepareNodeResponse
impl StructuralPartialEq for PrepareNodeResponse