pub struct ProvisionTenantRequest {
pub storage_tenant: String,
pub owner_app_id: String,
pub owner_client_id: String,
pub owner_client_secret: String,
}Expand description
Creates one storage tenant, its first owner application and that application’s credential in one durable metadata write. Only a caller with system#manage_system may perform this operation.
Fields
storage_tenant: StringExact lowercase ASCII DNS label (1..63 bytes). The server rejects rather
than normalizes other spellings. _anvil is reserved for Anvil’s
protected system tenant. Once claimed, a name remains bound to its first
stable tenant identity even after any future tenant release.
owner_app_id: Stringowner_client_id: Stringowner_client_secret: StringTrait Implementations
Sourceimpl Clone for ProvisionTenantRequest
impl Clone for ProvisionTenantRequest
Sourcefn clone(&self) -> ProvisionTenantRequest
fn clone(&self) -> ProvisionTenantRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProvisionTenantRequest
impl Debug for ProvisionTenantRequest
Sourceimpl Default for ProvisionTenantRequest
impl Default for ProvisionTenantRequest
impl Eq for ProvisionTenantRequest
Sourceimpl Hash for ProvisionTenantRequest
impl Hash for ProvisionTenantRequest
Sourceimpl Message for ProvisionTenantRequest
impl Message for ProvisionTenantRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProvisionTenantRequest
impl PartialEq for ProvisionTenantRequest
impl StructuralPartialEq for ProvisionTenantRequest