pub struct ReadFailure {
pub code: i32,
pub message: String,
}Fields
code: i32message: StringImplementations
Sourceimpl ReadFailure
impl ReadFailure
Sourcepub fn code(&self) -> ReadFailureCode
pub fn code(&self) -> ReadFailureCode
Returns the enum value of code, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code(&mut self, value: ReadFailureCode)
pub fn set_code(&mut self, value: ReadFailureCode)
Sets code to the provided enum value.