pub struct SetBucketVersioningResponse {
pub storage_tenant: String,
pub bucket: String,
pub versioning: i32,
pub changed: bool,
}Fields
storage_tenant: Stringbucket: Stringversioning: i32changed: boolImplementations
Sourceimpl SetBucketVersioningResponse
impl SetBucketVersioningResponse
Sourcepub fn versioning(&self) -> ObjectVersioning
pub fn versioning(&self) -> ObjectVersioning
Returns the enum value of versioning, or the default if the field is set to an invalid enum value.
Sourcepub fn set_versioning(&mut self, value: ObjectVersioning)
pub fn set_versioning(&mut self, value: ObjectVersioning)
Sets versioning to the provided enum value.