pub struct SystemApplicationRoleTarget {
pub role: i32,
}Fields
role: i32Implementations
Sourceimpl SystemApplicationRoleTarget
impl SystemApplicationRoleTarget
Sourcepub fn role(&self) -> SystemApplicationRole
pub fn role(&self) -> SystemApplicationRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: SystemApplicationRole)
pub fn set_role(&mut self, value: SystemApplicationRole)
Sets role to the provided enum value.