pub struct TenantApplicationRoleTarget {
pub role: i32,
}Fields
role: i32Implementations
Sourceimpl TenantApplicationRoleTarget
impl TenantApplicationRoleTarget
Sourcepub fn role(&self) -> TenantApplicationRole
pub fn role(&self) -> TenantApplicationRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: TenantApplicationRole)
pub fn set_role(&mut self, value: TenantApplicationRole)
Sets role to the provided enum value.