pub struct VectorIndexSpec {
pub json_pointer: String,
pub dimensions: u32,
pub metric: i32,
pub normalize: bool,
}Fields
json_pointer: Stringdimensions: u32metric: i32normalize: boolImplementations
Sourceimpl VectorIndexSpec
impl VectorIndexSpec
Sourcepub fn metric(&self) -> VectorMetric
pub fn metric(&self) -> VectorMetric
Returns the enum value of metric, or the default if the field is set to an invalid enum value.
Sourcepub fn set_metric(&mut self, value: VectorMetric)
pub fn set_metric(&mut self, value: VectorMetric)
Sets metric to the provided enum value.