pub struct WatchPrefixRequest {
pub prefix: Option<ObjectAddress>,
pub start: Option<Start>,
}Expand description
WatchPrefix is an unordered, at-least-once invalidation feed. Duplicates are legal and rapid changes to one path may be coalesced; intermediate versions are not promised. It carries no payload bytes and is not change-data-capture or an audit log. A consumer must reread each path until it observes at least minimum_path_version.
Fields
prefix: Option<ObjectAddress>path is a canonical path-segment prefix. Empty selects the whole bucket.
start: Option<Start>Trait Implementations
Sourceimpl Clone for WatchPrefixRequest
impl Clone for WatchPrefixRequest
Sourcefn clone(&self) -> WatchPrefixRequest
fn clone(&self) -> WatchPrefixRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WatchPrefixRequest
impl Debug for WatchPrefixRequest
Sourceimpl Default for WatchPrefixRequest
impl Default for WatchPrefixRequest
impl Eq for WatchPrefixRequest
Sourceimpl Hash for WatchPrefixRequest
impl Hash for WatchPrefixRequest
Sourceimpl Message for WatchPrefixRequest
impl Message for WatchPrefixRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for WatchPrefixRequest
impl PartialEq for WatchPrefixRequest
impl StructuralPartialEq for WatchPrefixRequest