pub trait AdministrationService:
Send
+ Sync
+ 'static {
// Required methods
fn prepare_node<'life0, 'async_trait>(
&'life0 self,
request: Request<PrepareNodeRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<PrepareNodeResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn provision_tenant<'life0, 'async_trait>(
&'life0 self,
request: Request<ProvisionTenantRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ProvisionTenantResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn create_application<'life0, 'async_trait>(
&'life0 self,
request: Request<CreateApplicationRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ApplicationCredential>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn rotate_application_credential<'life0, 'async_trait>(
&'life0 self,
request: Request<RotateApplicationCredentialRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ApplicationCredential>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn disable_application_credential<'life0, 'async_trait>(
&'life0 self,
request: Request<DisableApplicationCredentialRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ApplicationCredentialState>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn create_bucket<'life0, 'async_trait>(
&'life0 self,
request: Request<CreateBucketRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<CreateBucketResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn set_bucket_versioning<'life0, 'async_trait>(
&'life0 self,
request: Request<SetBucketVersioningRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<SetBucketVersioningResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn set_bucket_public_read<'life0, 'async_trait>(
&'life0 self,
request: Request<SetBucketPublicReadRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<SetBucketPublicReadResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn grant_application_role<'life0, 'async_trait>(
&'life0 self,
request: Request<ApplicationRoleRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ApplicationRoleResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn revoke_application_role<'life0, 'async_trait>(
&'life0 self,
request: Request<ApplicationRoleRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ApplicationRoleResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Generated trait containing gRPC methods that should be implemented for use with AdministrationServiceServer.
Required Methods
Sourcefn prepare_node<'life0, 'async_trait>(
&'life0 self,
request: Request<PrepareNodeRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<PrepareNodeResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn prepare_node<'life0, 'async_trait>(
&'life0 self,
request: Request<PrepareNodeRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<PrepareNodeResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Prepares one JOINING node identity after system#manage_system authorization. The server writes a mode-0600 one-time bundle and returns its local path for the administrator to copy to the new node and delete.
fn provision_tenant<'life0, 'async_trait>(
&'life0 self,
request: Request<ProvisionTenantRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ProvisionTenantResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn create_application<'life0, 'async_trait>(
&'life0 self,
request: Request<CreateApplicationRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ApplicationCredential>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn rotate_application_credential<'life0, 'async_trait>(
&'life0 self,
request: Request<RotateApplicationCredentialRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ApplicationCredential>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn disable_application_credential<'life0, 'async_trait>(
&'life0 self,
request: Request<DisableApplicationCredentialRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ApplicationCredentialState>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn create_bucket<'life0, 'async_trait>(
&'life0 self,
request: Request<CreateBucketRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<CreateBucketResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Sourcefn set_bucket_versioning<'life0, 'async_trait>(
&'life0 self,
request: Request<SetBucketVersioningRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<SetBucketVersioningResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn set_bucket_versioning<'life0, 'async_trait>(
&'life0 self,
request: Request<SetBucketVersioningRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<SetBucketVersioningResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Bucket versioning can move only from UNVERSIONED to ENABLED. Disabling a version-enabled bucket is deliberately unsupported.
Sourcefn set_bucket_public_read<'life0, 'async_trait>(
&'life0 self,
request: Request<SetBucketPublicReadRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<SetBucketPublicReadResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn set_bucket_public_read<'life0, 'async_trait>(
&'life0 self,
request: Request<SetBucketPublicReadRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<SetBucketPublicReadResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Enables or disables unauthenticated GET/list access for one bucket. The server represents anonymous readers as the reserved Zanzibar subject app:_anvil/anonymous; this does not create a manageable application and can never grant write access.
fn grant_application_role<'life0, 'async_trait>(
&'life0 self,
request: Request<ApplicationRoleRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ApplicationRoleResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn revoke_application_role<'life0, 'async_trait>(
&'life0 self,
request: Request<ApplicationRoleRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ApplicationRoleResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".