pub struct BulkPutRequest {
pub address: Option<ObjectAddress>,
pub bytes: Vec<u8>,
pub content_type: String,
pub command_id: String,
pub durability: i32,
}Expand description
Bulk puts carry their bounded payload inline because there is one enclosing unary request. They use the same canonical operation identity and semantics as the corresponding StartPut plus Put plus PutEnd sequence.
Fields
address: Option<ObjectAddress>bytes: Vec<u8>content_type: StringEmpty means unspecified; otherwise at most 512 UTF-8 bytes.
command_id: Stringdurability: i32Implementations
Sourceimpl BulkPutRequest
impl BulkPutRequest
Sourcepub fn durability(&self) -> Durability
pub fn durability(&self) -> Durability
Returns the enum value of durability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_durability(&mut self, value: Durability)
pub fn set_durability(&mut self, value: Durability)
Sets durability to the provided enum value.